onDestinationPath property
Callback that is called when a destination is selected.
The function receives parameter:
path: The path of the selected destination (can be null)
Implementation
final DestinationSelectedPath? onDestinationPath;
Callback that is called when a destination is selected.
The function receives parameter:
path: The path of the selected destination (can be null)final DestinationSelectedPath? onDestinationPath;