adaptive_navigation_view library
Classes
- The bar displayed at the top of the app. It can adapt itself to all the display modes.
-
An inherited widget that defines visual properties for
Panes in this widget's subtree. -
Defines default property values for descendant
Panewidgets. - The NavigationView control provides top-level navigation for your app. It adapts to a variety of screen sizes and supports both top and left navigation styles.
- Controls the state of a NavigationPane and NavigationView.
- PaneButton
- The PaneButton is an IconButton adorned with a "pane" icon. When pressed, the button invokes NavigationViewState.openPane for the associated NavigationView.pane.
- PaneController
- Provides interactive behavior for NavigationPane widgets.
- PaneControllerState
- State for a PaneController.
- PaneIndicator
- PaneItemDestination
- A navigation destination item for use in a NavigationPane.
- TogglePaneIntent
- WidthBreakpoint
Enums
- DestinationTypes
- DisplayMode
- You can use the PaneDisplayMode property to configure different navigation styles, or display modes, for the NavigationView
- PaneAlignment
- The possible alignments of a NavigationPane.
Constants
- The width of the Compact Navigation Pane
- The width of the Open Navigation Pane
Typedefs
- DestinationSelectedIndex = void Function(int? index)
- DestinationSelectedPath = void Function(String? path)
- PaneCallback = void Function(bool isOpened)